@@ -1,5 +1,3 @@
-use super::*;
-
 /// A list.
 pub enum ListState<F: ListFn> {
     /// The list has one item and a function to get a next sub list.
@@ -15,5 +13,5 @@ pub trait ListFn: Sized {
     /// A value which is returned when the list has no more items.
     type End;
     /// The main function which returns a list.
-    fn state(self) -> ListState<Self>;
+    fn next(self) -> ListState<Self>;
 }
